@@ -14,7 +14,7 @@ PyObject *extension_blend_images(PyObject *self, PyObject *args, PyObject *kwarg
     char *bottom_path, *top_path, *target_path, *algorithm;
     PyObject *is_inline;
     struct pcv_image bottom, top;
-	char *kwlist[] = {
+    char *kwlist[] = {
         "bottom_path",
         "top_path",
         "target_path",
@@ -23,9 +23,15 @@ PyObject *extension_blend_images(PyObject *self, PyObject *args, PyObject *kwarg
         NULL
     };
 
+    bottom_path = NULL;
+    top_path = NULL;
+    target_path = NULL;
+    algorithm = NULL;
+    is_inline = NULL;
+
     if(PyArg_ParseTupleAndKeywords(
         args,
-		kwargs,
+        kwargs,
         "sss|sO",
         &bottom_path,
         &top_path,
@@ -60,11 +66,11 @@ PyObject *extension_blend_images(PyObject *self, PyObject *args, PyObject *kwarg
 PyObject *extension_blend_multiple(PyObject *self, PyObject *args, PyObject *kwargs) {
     int run_inline;
     char demultiply, source_over, use_algorithms;
-    char *bottom_path, *top_path, *target_path, *algorithm;
+    char *bottom_path, *top_path, *target_path, *algorithm = NULL;
     struct pcv_image bottom, top;
     PyObject *paths, *iterator, *iteratorAlgorithms, *element, *first, *second,
         *is_inline, *algorithms, *algorithm_o;
-    Py_ssize_t size;
+    Py_ssize_t size, algorithms_size;
     char *kwlist[] = {
         "paths",
         "target_path",
@@ -78,6 +84,12 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args, PyObject *kwa
     PyObject *encoded;
 #endif
 
+    paths = NULL;
+    target_path = NULL;
+    algorithm = NULL;
+    algorithms = NULL;
+    is_inline = NULL;
+
     if(PyArg_ParseTupleAndKeywords(
         args,
         kwargs,
@@ -107,6 +119,15 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args, PyObject *kwa
     this is relevant to determine the kind of operation to be performed */
     size = PyList_Size(paths);
 
+    /* in case the use algorithms list strategy is used a small set of
+    verifications must be performed */
+    if(use_algorithms) {
+        algorithms_size = PyList_Size(algorithms);
+        if(algorithms_size != size - 1) {
+            abort_("[extension_blend_multiple] Invalid algorithms list size");
+        }
+    }
+
     /* in case the size of the provided sequence of paths
     is just one then a simple re-write operation should be
     performed, read from provided path and write to target path */
